@@ -1,9 +1,8 @@
-use crate::utils::{Error, ErrorKind, Result};
 use hyper::client::HttpConnector;
 use hyper::Body;
 use hyper::Client as HyperClient;
 
-use hyper_tls::HttpsConnector;
+use hyper_rustls::HttpsConnector;
 
 /// Client to make API requests easily.
 ///
@@ -11,7 +10,13 @@ use hyper_tls::HttpsConnector;
 /// of APIs are available for the client.
 pub struct SteamClient {
     pub(crate) client: HyperClient<HttpsConnector<HttpConnector>, Body>,
-    api_key: Option<String>,
+    pub(crate) api_key: Option<String>,
+}
+
+impl Default for SteamClient {
+    fn default() -> Self {
+        Self::new()
+    }
 }
 
 impl SteamClient {
@@ -19,7 +24,7 @@ impl SteamClient {
     ///
     /// Client with API key can use all available APIs.
     pub fn with_api_key(key: &str) -> Self {
-        let https_connector = HttpsConnector::new();
+        let https_connector = HttpsConnector::with_native_roots();
 
         SteamClient {
             client: HyperClient::builder().build::<_, Body>(https_connector),
@@ -31,18 +36,11 @@ impl SteamClient {
     ///
     /// Client without an API key can only use a subset of the APIs.
     pub fn new() -> Self {
-        let https_connector = HttpsConnector::new();
+        let https_connector = HttpsConnector::with_native_roots();
 
         SteamClient {
             client: HyperClient::builder().build::<_, Body>(https_connector),
             api_key: None,
         }
     }
-
-    pub(crate) fn api_key(&self) -> Result<String> {
-        match &self.api_key {
-            Some(key) => Ok(key.to_owned()),
-            None => Err(Error::new(ErrorKind::NoAPIKey)),
-        }
-    }
 }
